==> lme4_0.99875-1.orig.tar.gz: lme4/man/cake.Rd <==
\name{cake}
\alias{cake}
\docType{data}
\title{Breakage angle of chocolate cakes}
\description{  
  Data on the breakage angle of chocolate cakes made with three different
  recipes and baked at six different temperatures.  This is a split-plot
  design with the recipes being whole-units and the different
  temperatures being applied to sub-units (within replicates). The
  experimental notes suggest that the replicate numbering represents
  temporal ordering.   
}
\usage{data(cake)}
\format{
  A data frame with 270 observations on the following 5 variables.
  \describe{
    \item{\code{replicate}}{a factor with levels \code{1} to \code{15}}
    \item{\code{recipe}}{a factor with levels \code{A}, \code{B} and \code{C}}
    \item{\code{temperature}}{an ordered factor with levels \code{175}
      < \code{185} < \code{195} < \code{205} < \code{215} < \code{225}}
    \item{\code{angle}}{a numeric vector giving the angle at which the
      cake broke.}
    \item{\code{temp}}{numeric value of the baking temperature (degrees F).}
  }
}
\details{
  The \code{replicate} factor is nested within the \code{recipe} factor,
  and \code{temperature} is nested within \code{replicate}.
}
\source{
  Original data were presented in Cook (1938), and reported in Cochran
  and Cox (1957, p. 300).  Also cited in Lee, Nelder and Pawitan (2006).
}
\references{
Cook, F. E. (1938) \emph{Chocolate cake, I. Optimum baking temperature}.
Master's Thesis, Iowa State College.

Cochran, W. G., and Cox, G. M. (1957) \emph{Experimental designs}, 2nd Ed. New
York, John Wiley \& Sons.

Lee, Y., Nelder, J. A., and Pawitan, Y. (2006) \emph{Generalized linear models
with random effects. Unified analysis via H-likelihood}. Boca Raton,
Chapman and Hall/CRC.
}
\examples{
str(cake)
print(fm1 <- lmer(angle ~ recipe * temperature + (1|recipe:replicate), cake,
                  method = "ML"), corr = FALSE)
print(fm2 <- lmer(angle ~ recipe + temperature + (1|recipe:replicate), cake,
                  method = "ML"), corr = FALSE)
print(fm3 <- lmer(angle ~ recipe + temp + (1|recipe:replicate), cake,
                  method = "ML"), corr = FALSE)
anova(fm3, fm2, fm1)
}
\keyword{datasets}

==> lme4_0.999375-41.tar.gz: lme4/man/cake.Rd <==
\name{cake}
\alias{cake}
\docType{data}
\title{Breakage angle of chocolate cakes}
\description{  
  Data on the breakage angle of chocolate cakes made with three different
  recipes and baked at six different temperatures.  This is a split-plot
  design with the recipes being whole-units and the different
  temperatures being applied to sub-units (within replicates). The
  experimental notes suggest that the replicate numbering represents
  temporal ordering.   
}
\usage{data(cake)}
\format{
  A data frame with 270 observations on the following 5 variables.
  \describe{
    \item{\code{replicate}}{a factor with levels \code{1} to \code{15}}
    \item{\code{recipe}}{a factor with levels \code{A}, \code{B} and \code{C}}
    \item{\code{temperature}}{an ordered factor with levels \code{175}
      < \code{185} < \code{195} < \code{205} < \code{215} < \code{225}}
    \item{\code{angle}}{a numeric vector giving the angle at which the
      cake broke.}
    \item{\code{temp}}{numeric value of the baking temperature (degrees F).}
  }
}
\details{
  The \code{replicate} factor is nested within the \code{recipe} factor,
  and \code{temperature} is nested within \code{replicate}.
}
\source{
  Original data were presented in Cook (1938), and reported in Cochran
  and Cox (1957, p. 300).  Also cited in Lee, Nelder and Pawitan (2006).
}
\references{
Cook, F. E. (1938) \emph{Chocolate cake, I. Optimum baking temperature}.
Master's Thesis, Iowa State College.

Cochran, W. G., and Cox, G. M. (1957) \emph{Experimental designs}, 2nd Ed. New
York, John Wiley \& Sons.

Lee, Y., Nelder, J. A., and Pawitan, Y. (2006) \emph{Generalized linear models
with random effects. Unified analysis via H-likelihood}. Boca Raton,
Chapman and Hall/CRC.
}
\examples{
str(cake)
print(fm1 <- lmer(angle ~ recipe * temperature + (1|recipe:replicate), cake,
                  REML = FALSE), corr = FALSE)
print(fm2 <- lmer(angle ~ recipe + temperature + (1|recipe:replicate), cake,
                  REML = FALSE), corr = FALSE)
print(fm3 <- lmer(angle ~ recipe + temp + (1|recipe:replicate), cake,
                  REML = FALSE), corr = FALSE)
anova(fm3, fm2, fm1)
}
\keyword{datasets}
